ProviderV2Request

Enum ProviderV2Request 

pub enum ProviderV2Request {
    Initialize {
        config: ProviderConfigV2,
        control_handle: ProviderV2ControlHandle,
    },
    Start {
        options: StartOptions,
        responder: ProviderV2StartResponder,
    },
    Stop {
        responder: ProviderV2StopResponder,
    },
    Terminate {
        responder: ProviderV2TerminateResponder,
    },
    GetKnownCategories {
        responder: ProviderV2GetKnownCategoriesResponder,
    },
    NotifyBufferSaved {
        wrapped_count: u32,
        durable_data_end: u64,
        control_handle: ProviderV2ControlHandle,
    },
    Flush {
        control_handle: ProviderV2ControlHandle,
    },
#[non_exhaustive]
_UnknownMethod { ordinal: u64, control_handle: ProviderV2ControlHandle, method_type: MethodType, }, }
The provider interface which applications must implement and register with the TraceRegistry to participate in tracing.

Variants



Initialize

Initialize tracing and prepare for writing trace records for events in the specified categories into buffer. Tracing hasn’t started yet, a Start() call is still required.

At most one trace can be active at a time. Subsequent Initialize() requests received prior to a Terminate() call must be ignored.

Fields



Start

Begin tracing.

If tracing has already started the provider must ignore the request.



Stop

Stop tracing.

If tracing has already stopped the provider must ignore the request.

Once the provider has finished writing any final events to the trace buffer, it must send an OnStopped() event. Note that multiple Start,Stop requests can be received between Initialize,Terminate.

Fields



Terminate

Terminate tracing.

Tracing is stopped first if not already stopped.



GetKnownCategories

Gets the trace categories that might be produced by this provider.



NotifyBufferSaved

A buffer has been saved (streaming mode only).

Fields

wrapped_count: u32
durable_data_end: u64


Flush

Requests the provider its buffer to be read out, regardless of it is full or not.

Normally streaming mode only sends data once it has enough data to require a buffer swap and data flush. This produces fewer, but larger and bursty data transfers.

Some clients may want more regular smaller data transfers. These clients may instead manually invoke Flush whenever they are ready for data.

Fields



#[non_exhaustive]
_UnknownMethod

An interaction was received which does not match any known method.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
ordinal: u64

Ordinal of the method that was called.

method_type: MethodType

Implementations