pub struct ProviderV2GetKnownCategoriesResponder { /* private fields */ }Implementations
Sourceimpl ProviderV2GetKnownCategoriesResponder
impl ProviderV2GetKnownCategoriesResponder
Sourcepub fn send(self, categories: &[KnownCategory]) -> Result<(), Error>
pub fn send(self, categories: &[KnownCategory]) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
categories: &[KnownCategory],
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, categories: &[KnownCategory], ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.