pub struct ProviderV2GetKnownCategoriesResponse {
pub categories: Vec<KnownCategory>,
}Fields
categories: Vec<KnownCategory>Trait Implementations
Sourceimpl Clone for ProviderV2GetKnownCategoriesResponse
impl Clone for ProviderV2GetKnownCategoriesResponse
Sourcefn clone(&self) -> ProviderV2GetKnownCategoriesResponse
fn clone(&self) -> ProviderV2GetKnownCategoriesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<ProviderV2GetKnownCategoriesResponse, D> for ProviderV2GetKnownCategoriesResponsewhere
D: ResourceDialect,
impl<D> Decode<ProviderV2GetKnownCategoriesResponse, D> for ProviderV2GetKnownCategoriesResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> ProviderV2GetKnownCategoriesResponse
fn new_empty() -> ProviderV2GetKnownCategoriesResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<ProviderV2GetKnownCategoriesResponse, D> for &ProviderV2GetKnownCategoriesResponsewhere
D: ResourceDialect,
impl<D> Encode<ProviderV2GetKnownCategoriesResponse, D> for &ProviderV2GetKnownCategoriesResponsewhere
D: ResourceDialect,
Sourceimpl PartialEq for ProviderV2GetKnownCategoriesResponse
impl PartialEq for ProviderV2GetKnownCategoriesResponse
Sourcefn eq(&self, other: &ProviderV2GetKnownCategoriesResponse) -> bool
fn eq(&self, other: &ProviderV2GetKnownCategoriesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for ProviderV2GetKnownCategoriesResponse
impl TypeMarker for ProviderV2GetKnownCategoriesResponse
Sourcetype Owned = ProviderV2GetKnownCategoriesResponse
type Owned = ProviderV2GetKnownCategoriesResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ProviderV2GetKnownCategoriesResponse
impl ValueTypeMarker for ProviderV2GetKnownCategoriesResponse
Sourcetype Borrowed<'a> = &'a ProviderV2GetKnownCategoriesResponse
type Borrowed<'a> = &'a ProviderV2GetKnownCategoriesResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<ProviderV2GetKnownCategoriesResponse as TypeMarker>::Owned,
) -> <ProviderV2GetKnownCategoriesResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<ProviderV2GetKnownCategoriesResponse as TypeMarker>::Owned, ) -> <ProviderV2GetKnownCategoriesResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for ProviderV2GetKnownCategoriesResponse
impl StructuralPartialEq for ProviderV2GetKnownCategoriesResponse