pub struct ProviderV2InitializeRequest {
pub config: ProviderConfigV2,
}Fields
config: ProviderConfigV2Trait Implementations
Sourceimpl Debug for ProviderV2InitializeRequest
impl Debug for ProviderV2InitializeRequest
Sourceimpl Decode<ProviderV2InitializeRequest, DefaultFuchsiaResourceDialect> for ProviderV2InitializeRequest
impl Decode<ProviderV2InitializeRequest, DefaultFuchsiaResourceDialect> for ProviderV2InitializeRequest
Sourceimpl Encode<ProviderV2InitializeRequest, DefaultFuchsiaResourceDialect> for &mut ProviderV2InitializeRequest
impl Encode<ProviderV2InitializeRequest, DefaultFuchsiaResourceDialect> for &mut ProviderV2InitializeRequest
Sourceimpl<T0: Encode<ProviderConfigV2, DefaultFuchsiaResourceDialect>> Encode<ProviderV2InitializeRequest, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<ProviderConfigV2, DefaultFuchsiaResourceDialect>> Encode<ProviderV2InitializeRequest, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl ResourceTypeMarker for ProviderV2InitializeRequest
impl ResourceTypeMarker for ProviderV2InitializeRequest
Sourcetype Borrowed<'a> = &'a mut ProviderV2InitializeRequest
type Borrowed<'a> = &'a mut ProviderV2InitializeRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for ProviderV2InitializeRequest
impl TypeMarker for ProviderV2InitializeRequest
Sourcetype Owned = ProviderV2InitializeRequest
type Owned = ProviderV2InitializeRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Standalone<DefaultFuchsiaResourceDialect> for ProviderV2InitializeRequest
impl StructuralPartialEq for ProviderV2InitializeRequest