pub struct ProviderV2Marker;Trait Implementations
Sourceimpl Clone for ProviderV2Marker
impl Clone for ProviderV2Marker
Sourcefn clone(&self) -> ProviderV2Marker
fn clone(&self) -> ProviderV2Marker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderV2Marker
impl Debug for ProviderV2Marker
Sourceimpl Hash for ProviderV2Marker
impl Hash for ProviderV2Marker
Sourceimpl Ord for ProviderV2Marker
impl Ord for ProviderV2Marker
Sourcefn cmp(&self, other: &ProviderV2Marker) -> Ordering
fn cmp(&self, other: &ProviderV2Marker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ProviderV2Marker
impl PartialEq for ProviderV2Marker
Sourceimpl PartialOrd for ProviderV2Marker
impl PartialOrd for ProviderV2Marker
Sourceimpl ProtocolMarker for ProviderV2Marker
impl ProtocolMarker for ProviderV2Marker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) ProviderV2"
const DEBUG_NAME: &'static str = "(anonymous) ProviderV2"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = ProviderV2Proxy
type Proxy = ProviderV2Proxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = ProviderV2RequestStream
type RequestStream = ProviderV2RequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = ProviderV2SynchronousProxy
type SynchronousProxy = ProviderV2SynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for ProviderV2Marker
impl Eq for ProviderV2Marker
impl StructuralPartialEq for ProviderV2Marker