pub struct ProviderV2OnAlertRequest {
pub name: String,
}Fields
name: StringTrait Implementations
Sourceimpl Clone for ProviderV2OnAlertRequest
impl Clone for ProviderV2OnAlertRequest
Sourcefn clone(&self) -> ProviderV2OnAlertRequest
fn clone(&self) -> ProviderV2OnAlertRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderV2OnAlertRequest
impl Debug for ProviderV2OnAlertRequest
Sourceimpl<D> Decode<ProviderV2OnAlertRequest, D> for ProviderV2OnAlertRequestwhere
D: ResourceDialect,
impl<D> Decode<ProviderV2OnAlertRequest, D> for ProviderV2OnAlertRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> ProviderV2OnAlertRequest
fn new_empty() -> ProviderV2OnAlertRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<ProviderV2OnAlertRequest, D> for &ProviderV2OnAlertRequestwhere
D: ResourceDialect,
impl<D> Encode<ProviderV2OnAlertRequest, D> for &ProviderV2OnAlertRequestwhere
D: ResourceDialect,
Sourceimpl Hash for ProviderV2OnAlertRequest
impl Hash for ProviderV2OnAlertRequest
Sourceimpl Ord for ProviderV2OnAlertRequest
impl Ord for ProviderV2OnAlertRequest
Sourcefn cmp(&self, other: &ProviderV2OnAlertRequest) -> Ordering
fn cmp(&self, other: &ProviderV2OnAlertRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ProviderV2OnAlertRequest
impl PartialEq for ProviderV2OnAlertRequest
Sourceimpl PartialOrd for ProviderV2OnAlertRequest
impl PartialOrd for ProviderV2OnAlertRequest
Sourceimpl TypeMarker for ProviderV2OnAlertRequest
impl TypeMarker for ProviderV2OnAlertRequest
Sourcetype Owned = ProviderV2OnAlertRequest
type Owned = ProviderV2OnAlertRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ProviderV2OnAlertRequest
impl ValueTypeMarker for ProviderV2OnAlertRequest
Sourcetype Borrowed<'a> = &'a ProviderV2OnAlertRequest
type Borrowed<'a> = &'a ProviderV2OnAlertRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<ProviderV2OnAlertRequest as TypeMarker>::Owned,
) -> <ProviderV2OnAlertRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<ProviderV2OnAlertRequest as TypeMarker>::Owned, ) -> <ProviderV2OnAlertRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Eq for ProviderV2OnAlertRequest
impl Persistable for ProviderV2OnAlertRequest
impl StructuralPartialEq for ProviderV2OnAlertRequest