pub struct RegistryProxy { /* private fields */ }Implementations
Sourceimpl RegistryProxy
impl RegistryProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.tracing.provider/Registry.
Sourcepub fn take_event_stream(&self) -> RegistryEventStream
pub fn take_event_stream(&self) -> RegistryEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn register_provider(
&self,
provider: ClientEnd<ProviderMarker>,
pid: u64,
name: &str,
) -> Result<(), Error>
pub fn register_provider( &self, provider: ClientEnd<ProviderMarker>, pid: u64, name: &str, ) -> Result<(), Error>
Registers the trace provider.
Note: Registration is asynchronous, it’s only at some point after this
returns that the provider is actually registered.
To unregister, simply close the Provider pipe.
pid is the process id of the provider, name is the name of the
provider. Both of these are used in logging and diagnostic messages.
Deprecation
Use “RegisterV2” instead to use the FIDL-based coordination protocol.
Sourcepub fn register_provider_synchronously(
&self,
provider: ClientEnd<ProviderMarker>,
pid: u64,
name: &str,
) -> QueryResponseFut<(i32, bool), DefaultFuchsiaResourceDialect>
pub fn register_provider_synchronously( &self, provider: ClientEnd<ProviderMarker>, pid: u64, name: &str, ) -> QueryResponseFut<(i32, bool), DefaultFuchsiaResourceDialect>
Registers the trace provider synchronously. The call doesn’t return
until the provider is registered.
On return s is ZX_OK if registration was successful.
started is true if tracing has already started, which is a hint to
the provider to wait for the Start() message before continuing if it
wishes to not drop trace records before Start() is received.
To unregister, simply close the Provider pipe.
pid is the process id of the provider, name is the name of the
provider. Both of these are used in logging and diagnostic messages.
Deprecation
Use “RegisterV2Synchronously” instead to use the FIDL-based coordination protocol.
Sourcepub fn register_v2(
&self,
provider: ClientEnd<ProviderV2Marker>,
pid: u64,
name: &str,
) -> Result<(), Error>
pub fn register_v2( &self, provider: ClientEnd<ProviderV2Marker>, pid: u64, name: &str, ) -> Result<(), Error>
Registers the trace provider using the V2 protocol.
Note: Registration is asynchronous, it’s only at some point after this returns that the provider is actually registered.
To unregister, close the provider connection.
Sourcepub fn register_v2_synchronously(
&self,
provider: ClientEnd<ProviderV2Marker>,
pid: u64,
name: &str,
) -> QueryResponseFut<RegistryRegisterV2SynchronouslyResult, DefaultFuchsiaResourceDialect>
pub fn register_v2_synchronously( &self, provider: ClientEnd<ProviderV2Marker>, pid: u64, name: &str, ) -> QueryResponseFut<RegistryRegisterV2SynchronouslyResult, DefaultFuchsiaResourceDialect>
Registers the trace provider synchronously using the V2 protocol.
The call doesn’t return until the provider is registered. Most callers should use RegisterV2 unless they need to synchronize with they tracing system to ensure that specific events are captured.
To unregister, close the provider connection.