pub struct RegistryRegisterV2Request {
pub provider: ClientEnd<ProviderV2Marker>,
pub pid: u64,
pub name: String,
}Fields
provider: ClientEnd<ProviderV2Marker>pid: u64The process id of the provider used for logging and diagnostics
name: StringThe name of the provider used for logging and diagnostics