pub struct RegistryRegisterV2SynchronouslyResponse {
pub started: bool,
}Fields
started: booltrue if tracing has already started, which is a hint to the provider to wait for the Start() message before continuing if it wishes to not drop trace records before Start() is received.