RegistrySynchronousProxy

Struct RegistrySynchronousProxy 

pub struct RegistrySynchronousProxy { /* private fields */ }

Implementations

Source

impl RegistrySynchronousProxy

pub fn new(channel: Channel) -> Self

pub fn into_channel(self) -> Channel

pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<RegistryEvent, Error>

Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.

pub fn register_provider( &self, provider: ClientEnd<ProviderMarker>, pid: u64, name: &str, ) -> Result<(), Error>

Registers the trace provider. Note: Registration is asynchronous, it’s only at some point after this returns that the provider is actually registered. To unregister, simply close the Provider pipe. pid is the process id of the provider, name is the name of the provider. Both of these are used in logging and diagnostic messages.

Deprecation

Use “RegisterV2” instead to use the FIDL-based coordination protocol.

pub fn register_provider_synchronously( &self, provider: ClientEnd<ProviderMarker>, pid: u64, name: &str, ___deadline: MonotonicInstant, ) -> Result<(i32, bool), Error>

Registers the trace provider synchronously. The call doesn’t return until the provider is registered. On return s is ZX_OK if registration was successful. started is true if tracing has already started, which is a hint to the provider to wait for the Start() message before continuing if it wishes to not drop trace records before Start() is received. To unregister, simply close the Provider pipe. pid is the process id of the provider, name is the name of the provider. Both of these are used in logging and diagnostic messages.

Deprecation

Use “RegisterV2Synchronously” instead to use the FIDL-based coordination protocol.

pub fn register_v2( &self, provider: ClientEnd<ProviderV2Marker>, pid: u64, name: &str, ) -> Result<(), Error>

Registers the trace provider using the V2 protocol.

Note: Registration is asynchronous, it’s only at some point after this returns that the provider is actually registered.

To unregister, close the provider connection.

pub fn register_v2_synchronously( &self, provider: ClientEnd<ProviderV2Marker>, pid: u64, name: &str, ___deadline: MonotonicInstant, ) -> Result<RegistryRegisterV2SynchronouslyResult, Error>

Registers the trace provider synchronously using the V2 protocol.

The call doesn’t return until the provider is registered. Most callers should use RegisterV2 unless they need to synchronize with they tracing system to ensure that specific events are captured.

To unregister, close the provider connection.